@@ -15,8 +15,6 @@ namespace KWayland
 namespace Server
 {
 
-class Display;
-
 enum class RelativePointerInterfaceVersion {
     /**
      * zwp_relative_pointer_manager_v1 and zwp_relative_pointer_v1
@@ -38,7 +36,7 @@ class KWAYLANDSERVER_EXPORT RelativePointerManagerInterface : public Global
 {
     Q_OBJECT
 public:
-    virtual ~RelativePointerManagerInterface();
+    ~RelativePointerManagerInterface() override;
 
     /**
      * @returns The interface version used by this RelativePointerManagerInterface
